@@ -18,23 +18,26 @@ class NotificationManager:
         self._logger = logger
         self._to_publish = []
 
-    def stage(self, event_type: str, message, group_id: str):
-        self._to_publish.append((event_type, message, group_id))
+    def stage(self, event_type: str, message, group_id: str, event_cause: str = None):
+        self._to_publish.append((event_type, message, group_id, event_cause))
 
     def flush(self):
         with concurrent.futures.ThreadPoolExecutor(max_workers=16) as executor:
             for to_publish in self._to_publish:
                 executor.submit(self.publish, *to_publish)
 
-    def publish(self, event_type: str, message, group_id: str):
+    def publish(self, event_type: str, message, group_id: str, event_cause: str = None):
         if type(message) is not str:
             message = message.json()
         try:
-            response = self._publish(
+            message_attributes = {"eventType": event_type}
+            if event_cause:
+                message_attributes["eventCause"] = event_cause
+            self._publish(
                 message=message,
                 message_deduplication_id=uuid4().hex,
                 group_id=group_id,
-                message_attributes={"eventType": event_type},
+                message_attributes=message_attributes,
             )
         except InternalError as e:
             if self._logger:
@@ -52,7 +55,6 @@ class NotificationManager:
                 MessageGroupId=group_id,
                 MessageAttributes=message_attributes,
             )
-            return response
         except botocore.exceptions.ClientError as e:
             raise InternalError() from e
 
